@@ -3,12 +3,12 @@
  * NAGIOS.C - Core Program Code For Nagios
  *
  * Program: Nagios
- * Version: 2.7
+ * Version: 2.9
  * License: GPL
  * Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)
  *
  * First Written:   01-28-1999 (start of development)
- * Last Modified:   01-19-2007
+ * Last Modified:   04-10-2007
  *
  * Description:
  *
@@ -142,6 +142,9 @@ int             log_rotation_method=LOG_ROTATION_NONE;
 
 int             sigshutdown=FALSE;
 int             sigrestart=FALSE;
+char            *sigs[]={"EXIT","HUP","INT","QUIT","ILL","TRAP","ABRT","BUS","FPE","KILL","USR1","SEGV","USR2","PIPE","ALRM","TERM","STKFLT","CHLD","CONT","STOP","TSTP","TTIN","TTOU","URG","XCPU","XFSZ","VTALRM","PROF","WINCH","IO","PWR","UNUSED","ZERR","DEBUG",(char *)NULL};
+int             caught_signal=FALSE;
+int             sig_id=0;
 
 int             restarting=FALSE;
 
@@ -223,7 +226,7 @@ int main(int argc, char **argv){
 	char buffer[MAX_INPUT_BUFFER];
 	int display_license=FALSE;
 	int display_help=FALSE;
-	int c;
+	int c=0,x=0;
 
 #ifdef HAVE_GETOPT_H
 	int option_index=0;
@@ -711,6 +714,24 @@ int main(int argc, char **argv){
 			/* (doesn't return until a restart or shutdown signal is encountered) */
 			event_execution_loop();
 
+			/* 03/01/2007 EG Moved from sighandler() to prevent FUTEX locking problems under NPTL */
+			/* 03/21/2007 EG SIGSEGV signals are still logged in sighandler() so we don't loose them */
+			/* did we catch a signal? */
+			if(caught_signal==TRUE){
+
+				if(sig_id==SIGHUP)
+					snprintf(buffer,sizeof(buffer),"Caught SIGHUP, restarting...\n");
+				else if(sig_id!=SIGSEGV)
+					snprintf(buffer,sizeof(buffer),"Caught SIG%s, shutting down...\n",sigs[sig_id]);
+				buffer[sizeof(buffer)-1]='\x0';
+
+#ifdef DEBUG2
+				printf("%s\n",buffer);
+#endif
+
+				write_to_all_logs(buffer,NSLOG_PROCESS_INFO);
+				}
+
 #ifdef USE_EVENT_BROKER
 			/* send program data to broker */
 			broker_program_state(NEBTYPE_PROCESS_EVENTLOOPEND,NEBFLAG_NONE,NEBATTR_NONE,NULL);
