@@ -3,7 +3,7 @@
  * HISTORY.C - Nagios History CGI
  *
  * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 11-10-2007
+ * Last Modified: 04-10-2007
  *
  * This CGI program will display the history for the specified host.
  * If no host is specified, the history for all hosts will be displayed.
@@ -379,7 +379,6 @@ int process_cgivars(void){
 				host_name="";
 			else
 				strcpy(host_name,variables[x]);
-			strip_html_brackets(host_name);
 
 			display_type=DISPLAY_HOSTS;
 
@@ -402,7 +401,6 @@ int process_cgivars(void){
 				svc_description="";
 			else
 				strcpy(svc_description,variables[x]);
-			strip_html_brackets(svc_description);
 
 			display_type=DISPLAY_SERVICES;
 		        }
@@ -903,7 +901,7 @@ void get_history(void){
 
 				if(display_frills==TRUE)
 					printf("<img align='left' src='%s%s' alt='%s' title='%s'>",url_images_path,image,image_alt,image_alt);
-				printf("[%s] %s<br clear='all'>\n",date_time,html_encode(temp_buffer));
+				printf("[%s] %s<br clear='all'>\n",date_time,strip_plugin_html(temp_buffer));
 				found_line=TRUE;
 			        }
 		        }
